@@ -24,9 +24,9 @@
 
 #include "Screen.h"
 
-static char useString[] = "[ moviePtr [duration] [fps] [width] [height] [count] [aspectRatio]]=Screen('OpenMovie', windowPtr, moviefile [, async=0] [, preloadSecs=1] [, specialFlags1=0][, pixelFormat=4][, maxNumberThreads=-1]);";
+static char useString[] = "[ moviePtr [duration] [fps] [width] [height] [count] [aspectRatio]]=Screen('OpenMovie', windowPtr, moviefile [, async=0] [, preloadSecs=1] [, specialFlags1=0][, pixelFormat=4][, maxNumberThreads=-1][, movieOptions]);";
 static char synopsisString[] = 
-		"Try to open the multimediafile 'moviefile' for playback in onscreen window 'windowPtr' and "
+        "Try to open the multimediafile 'moviefile' for playback in onscreen window 'windowPtr' and "
         "return a handle 'moviePtr' on success.\n"
         "This function requires the GStreamer multi-media framework to be installed on your system.\n"
         "The following movie properties are optionally returned: 'duration' Total duration of movie in seconds. "
@@ -36,7 +36,7 @@ static char synopsisString[] =
         "'width' Width of the images contained in the movie. 'height' Height of the images.\n"
         "'count' Total number of videoframes in the movie. Determined by counting, so querying 'count' "
         "can significantly increase the execution time of this command.\n"
-		"'aspectRatio' Pixel aspect ratio of pixels in the video frames. Typically 1.0 for square pixels.\n"
+        "'aspectRatio' Pixel aspect ratio of pixels in the video frames. Typically 1.0 for square pixels.\n"
         "If you want to play multiple movies in succession with lowest possible delay inbetween the movies "
         "then you can ask PTB to load a movie in the background while another movie is still playing: "
         "Call this function with the 'async' flag set to 1. This will initiate the background load operation. "
@@ -48,24 +48,24 @@ static char synopsisString[] =
         "parameter. This will queue the movie 'moviefile' as a successor to the currently playing moviefile in "
         "'moviePtr'. Queuing movies this way is more efficient than async flag setting 1, although also more "
         "restricted.\n"
-		"If the 'async' flag also contains the number 4 or is equal to 4, then movie playback will not automatically "
-		"drop video frames to preserve audio-video sync in case fetching and display of video frames by your script "
-		"is delayed or too slow. This has the disadvantage that you'll need to take care of audio-video sync and framerate "
-		"control yourself by proper comparison of movie presentation timestamps and GetSecs or Screen('Flip') timestamps. "
-		"The advantage is, that after start of playback the playback engine can internally predecode and buffer up to "
-		"'preloadSecs' seconds worth of video and audio data. This may allow complex movies to play more smoothly or "
-		"at higher framerates.\n"
-		"'preloadSecs' This optional parameter allows to ask Screen() to buffer at least up to 'preloadSecs' "
-		"seconds of the movie. This potentially allows for more stutter-free playback, but your mileage "
-		"may vary, depending on movie format, storage medium and lots of other factors. In most cases, the default "
-		"setting is perfectly sufficient. The special setting -1 means: Try to buffer the whole movie. Caution: Long "
-		"movies may cause your system to run low on memory or disc space and have disastrous effects on playback performance! "
-		"Also, the exact type of buffering applied depends a lot on the movie playback engine and movie format, "
-		"but it usually affects the buffering behaviour and capacity of buffering in some meaningful way.\n"
-		"'specialFlags1' Optional flags, numbers to be added together: 1 = Use YUV video decoding instead of RGBA, if "
-		"supported by movie codec and GPU - May be more efficient. 2 = Don't decode and use sound - May be more efficient. "
-		"On Linux you may need to specify a setting of 2 if you try to use movie playback at the same time as "
-		"PsychPortAudio sound output, otherwise movie playback may hang. A flag of 4 will draw motion vectors on top "
+        "If the 'async' flag also contains the number 4 or is equal to 4, then movie playback will not automatically "
+        "drop video frames to preserve audio-video sync in case fetching and display of video frames by your script "
+        "is delayed or too slow. This has the disadvantage that you'll need to take care of audio-video sync and framerate "
+        "control yourself by proper comparison of movie presentation timestamps and GetSecs or Screen('Flip') timestamps. "
+        "The advantage is, that after start of playback the playback engine can internally predecode and buffer up to "
+        "'preloadSecs' seconds worth of video and audio data. This may allow complex movies to play more smoothly or "
+        "at higher framerates.\n"
+        "'preloadSecs' This optional parameter allows to ask Screen() to buffer at least up to 'preloadSecs' "
+        "seconds of the movie. This potentially allows for more stutter-free playback, but your mileage "
+        "may vary, depending on movie format, storage medium and lots of other factors. In most cases, the default "
+        "setting is perfectly sufficient. The special setting -1 means: Try to buffer the whole movie. Caution: Long "
+        "movies may cause your system to run low on memory or disc space and have disastrous effects on playback performance! "
+        "Also, the exact type of buffering applied depends a lot on the movie playback engine and movie format, "
+        "but it usually affects the buffering behaviour and capacity of buffering in some meaningful way.\n"
+        "'specialFlags1' Optional flags, numbers to be added together: 1 = Use YUV video decoding instead of RGBA, if "
+        "supported by movie codec and GPU - May be more efficient. 2 = Don't decode and use sound - May be more efficient. "
+        "On Linux you may need to specify a setting of 2 if you try to use movie playback at the same time as "
+        "PsychPortAudio sound output, otherwise movie playback may hang. A flag of 4 will draw motion vectors on top "
         "of decoded video frames, for debugging or entertainment. A flag of 8 will ask the video decoder to skip all "
         "B-Frames during decoding to reduce processor load on very slow machines. Not all codecs may support flags 4 or "
         "8, in which case these flags are silently ignored. A flag of 16 asks Screen to convert all video textures "
@@ -120,7 +120,19 @@ static char synopsisString[] =
         "and can provide a significant performance boost on multi-core computers. Specify a discrete non-zero number of threads "
         "if you want to benefit from multi-core decoding but want to prevent movie playback from using up all available computation "
         "power, e.g., because you want to run some other timing-sensitive tasks in parallel and want to make sure to leave some processor "
-        "cores dedicated to them.\n";
+        "cores dedicated to them.\n"
+        "'movieOptions' Optional text string which encodes additional options for playback of the movie. Parameters are "
+        "keyword=value pairs, separated by three colons ::: if there are multiple parameters. Currently supported keywords:\n"
+        "AudioSink=GStreamerSinkSpec -- GStreamerSinkSpec is a GStreamer gst-launch line style specification for a audio sink "
+        "plugin and its parameters. This allows to customize where the audio of a movie is sent during playback and with which "
+        "parameters. By default, the autoaudiosink plugin is used, which automatically chooses audio output and parameters, based "
+        "on your system and user settings. Most often this is what you want. Sometimes you may want to have more control over "
+        "outputs, e.g., if your system has multiple sound cards installed and you want to route audio output to a specific "
+        "card and output connector. Example use of the parameter: 'AudioSink=pulseaudiosink device=MyCardsOutput1' would use the "
+        "Linux pulseaudiosink plugin to send sound data to the output named 'MyCardsOutput1' via the PulseAudio sound server commonly "
+        "used on Linux desktop systems.\n"
+        "If you set a Screen() verbosity level of 4 or higher, Screen() will print out the actually used audio output at the end "
+        "of movie playback on operating systems which support this. This can help debugging issues with audio routing if you don't hear sound.\n";
 
 static char seeAlsoString[] = "CloseMovie PlayMovie GetMovieImage GetMovieTimeIndex SetMovieTimeIndex";
 
@@ -130,6 +142,8 @@ PsychError SCREENOpenMovie(void)
 {
         PsychWindowRecordType                   *windowRecord;
         char                                    *moviefile;
+        char                                    *movieOptions;
+        char                                    dummmyOptions[1];
         int                                     moviehandle = -1;
         int                                     framecount;
         double                                  durationsecs;
@@ -138,7 +152,7 @@ PsychError SCREENOpenMovie(void)
         int                                     width;
         int                                     height;
         int                                     asyncFlag = 0;
-		int                                     specialFlags1 = 0;
+        int                                     specialFlags1 = 0;
         static psych_bool                       firstTime = TRUE;
         double                                  preloadSecs = 1;
         int                                     rc;
@@ -150,15 +164,15 @@ PsychError SCREENOpenMovie(void)
             firstTime = FALSE;
             asyncmovieinfo.asyncstate = 0; // State = No async open in progress.
         }
-        
+
         // All sub functions should have these two lines
         PsychPushHelp(useString, synopsisString, seeAlsoString);
         if(PsychIsGiveHelp()) {PsychGiveHelp(); return(PsychError_none);};
 
-        PsychErrorExit(PsychCapNumInputArgs(7));            // Max. 7 input args.
+        PsychErrorExit(PsychCapNumInputArgs(8));            // Max. 8 input args.
         PsychErrorExit(PsychRequireNumInputArgs(1));        // Min. 1 input args required.
         PsychErrorExit(PsychCapNumOutputArgs(7));           // Max. 7 output args.
-        
+
         // Get the window record from the window record argument and get info from the window record
         windowRecord = NULL;
         PsychAllocInWindowRecordArg(kPsychUseDefaultArgPosition, FALSE, &windowRecord);
@@ -166,7 +180,7 @@ PsychError SCREENOpenMovie(void)
         if(windowRecord && !PsychIsOnscreenWindow(windowRecord)) {
             PsychErrorExitMsg(PsychError_user, "OpenMovie called on something else than an onscreen window.");
         }
-        
+
         // Get the movie name string:
         moviefile = NULL;
         PsychAllocInCharArg(2, kPsychArgRequired, &moviefile);
@@ -179,7 +193,7 @@ PsychError SCREENOpenMovie(void)
 
         // Get the (optional) specialFlags1:
         PsychCopyInIntegerArg(5, FALSE, &specialFlags1);
-		if (specialFlags1 < 0) PsychErrorExitMsg(PsychError_user, "OpenMovie called with invalid 'specialFlags1' setting! Only positive values allowed.");
+        if (specialFlags1 < 0) PsychErrorExitMsg(PsychError_user, "OpenMovie called with invalid 'specialFlags1' setting! Only positive values allowed.");
 
         // Get the (optional) pixelFormat:
         PsychCopyInIntegerArg(6, FALSE, &pixelFormat);
@@ -188,7 +202,14 @@ PsychError SCREENOpenMovie(void)
         // Get the (optional) maxNumberThreads:
         PsychCopyInIntegerArg(7, FALSE, &maxNumberThreads);
         if (maxNumberThreads < -1) PsychErrorExitMsg(PsychError_user, "OpenMovie called with invalid 'maxNumberThreads' setting! Only values of -1 or greater are allowed.");
-    
+
+        // Get the (optional) movie options string: As PsychAllocInCharArg() no-ops if
+        // the optional string isn't provided, we need to point movieOptions to an empty
+        // 0-terminated string by default, so we don't have a dangling pointer:
+        dummmyOptions[0] = 0;
+        movieOptions = &dummmyOptions[0];
+        PsychAllocInCharArg(8, FALSE, &movieOptions);
+
         // Queueing of a new movie for seamless playback requested?
         if (asyncFlag & 2) {
             // Yes. Do a special call, just passing the moviename of the next
@@ -196,7 +217,7 @@ PsychError SCREENOpenMovie(void)
             // preloadSecs:
             moviehandle = (int) preloadSecs;
             preloadSecs = 0;
-            PsychCreateMovie(windowRecord, moviefile, preloadSecs, &moviehandle, asyncFlag, specialFlags1, pixelFormat, maxNumberThreads);
+            PsychCreateMovie(windowRecord, moviefile, preloadSecs, &moviehandle, asyncFlag, specialFlags1, pixelFormat, maxNumberThreads, movieOptions);
             if (moviehandle == -1) PsychErrorExitMsg(PsychError_user, "Could not queue new moviefile for gapless playback.");
             return(PsychError_none);
         }
@@ -206,8 +227,8 @@ PsychError SCREENOpenMovie(void)
             // No. We should just synchronously open the movie:
 
             // Try to open the named 'moviefile' and create & initialize a corresponding movie object.
-            // A MATLAB handle to the movie object is returned upon successfull operation.
-            PsychCreateMovie(windowRecord, moviefile, preloadSecs, &moviehandle, asyncFlag, specialFlags1, pixelFormat, maxNumberThreads);
+            // A handle to the movie object is returned upon successfull operation.
+            PsychCreateMovie(windowRecord, moviefile, preloadSecs, &moviehandle, asyncFlag, specialFlags1, pixelFormat, maxNumberThreads, movieOptions);
         }
         else {
             // Asynchronous open operation requested or running:
@@ -220,8 +241,9 @@ PsychError SCREENOpenMovie(void)
                     asyncmovieinfo.asyncFlag = asyncFlag;
                     asyncmovieinfo.specialFlags1 = specialFlags1;
                     asyncmovieinfo.pixelFormat = pixelFormat;
-					asyncmovieinfo.maxNumberThreads = maxNumberThreads;
-                    
+                    asyncmovieinfo.maxNumberThreads = maxNumberThreads;
+                    asyncmovieinfo.movieOptions = strdup(movieOptions);
+
                     if (windowRecord) {
                         memcpy(&asyncmovieinfo.windowRecord, windowRecord, sizeof(PsychWindowRecordType));
                     } else {
@@ -232,20 +254,20 @@ PsychError SCREENOpenMovie(void)
 
                     // Increase our scheduling priority to basic RT priority: This way we should get
                     // more cpu time for our PTB main thread than the async. background prefetch-thread:
-					// On Windows we must not go higher than basePriority 1 (HIGH PRIORITY) or bad interference can happen.
-					// On OS/X we use basePriority 2 for robust realtime, using up to (4+1) == 5 msecs of time in every 10 msecs slice, allowing for up to 1 msec jitter/latency for ops.
-					// On Linux we just use standard basePriority 2 RT-FIFO scheduling and trust the os to do the right thing.
+                    // On Windows we must not go higher than basePriority 1 (HIGH PRIORITY) or bad interference can happen.
+                    // On OS/X we use basePriority 2 for robust realtime, using up to (4+1) == 5 msecs of time in every 10 msecs slice, allowing for up to 1 msec jitter/latency for ops.
+                    // On Linux we just use standard basePriority 2 RT-FIFO scheduling and trust the os to do the right thing.
                     if ((rc=PsychSetThreadPriority(NULL, ((PSYCH_SYSTEM == PSYCH_WINDOWS) ? 1 : 2), ((PSYCH_SYSTEM == PSYCH_OSX) ? 4 : 0)))!=0) {
                         printf("PTB-WARNING: In OpenMovie(): Failed to raise priority of main thread [System error %i]. Expect movie timing problems.\n", rc);
                     }
 
                     // Start our own movie loader Posix-Thread:
                     PsychCreateThread(&asyncmovieinfo.pid, NULL, PsychAsyncCreateMovie, &asyncmovieinfo);
-                    
+
                     // Async movie open initiated. We return control to host environment:
                     return(PsychError_none);
                 break;
-                    
+
                 case 1: // Async open operation in progress, but not yet finished.
                     // Should we wait for completion or just return?
                     if (asyncFlag & 1) {
@@ -254,7 +276,7 @@ PsychError SCREENOpenMovie(void)
                         return(PsychError_none);
                     }
                     // We fall through to case 2 - Wait for "Load operation successfully finished."
-                
+
                 case 2: // Async open operation successfully finished. Parse asyncinfo struct and return it to host environment:
                     // We need to join our terminated worker thread to release its ressources. If the worker-thread
                     // isn't done yet (fallthrough from case 1 for sync. wait), this join will block us until worker
@@ -263,14 +285,20 @@ PsychError SCREENOpenMovie(void)
 
                     asyncmovieinfo.asyncstate = 0; // Reset state to idle:
                     moviehandle = asyncmovieinfo.moviehandle;
-                    
+
+                    // Release options string:
+                    free(asyncmovieinfo.movieOptions);
+
                     // Movie successfully opened?
                     if (moviehandle < 0) {
                         // Movie loading failed for some reason.
                         printf("PTB-ERROR: When trying to asynchronously load movie %s, the operation failed: ", asyncmovieinfo.moviename);
+                        free(asyncmovieinfo.moviename);
                         PsychErrorExitMsg(PsychError_user, "Asynchronous loading of the movie failed.");
                     }
-                    
+
+                    free(asyncmovieinfo.moviename);
+
                     // We can fall out of the switch statement and continue with the standard synchronous load code as if
                     // the movie had been loaded synchronously.
                 break;
@@ -280,11 +308,10 @@ PsychError SCREENOpenMovie(void)
         }
 
         // Upon sucessfull completion, we'll have a valid handle in 'moviehandle'.
-        // Return it to Matlab-world:
         PsychCopyOutDoubleArg(1, TRUE, (double) moviehandle);
 
         // Retrieve infos about new movie:
-        
+
         // Is the "count" output argument (total number of frames) requested by user?
         if (PsychGetNumOutputArgs() > 5) {
             // Yes. Query the framecount (expensive!) and return it:
@@ -302,8 +329,8 @@ PsychError SCREENOpenMovie(void)
         PsychCopyOutDoubleArg(5, FALSE, (double) height);
         PsychCopyOutDoubleArg(7, FALSE, (double) aspectRatio);
 
-	// Ready!
-	return(PsychError_none);
+    // Ready!
+    return(PsychError_none);
 }
 
 // Functions for movie creation/editing/writing:
