@@ -32,6 +32,8 @@
 #include <time.h>
 #include <errno.h>
 #include <sched.h>
+// utsname for uname() so we can find out on which kernel we're running:
+#include <sys/utsname.h>
 
 /*
  *		file local state variables
@@ -262,24 +264,40 @@ double PsychOSGetLinuxMonotonicTime(void)
  */
 double PsychOSMonotonicToRefTime(double monotonicTime)
 {
-	double now, tMonotonic;
-	// Get current reftime:
-	PsychGetAdjustedPrecisionTimerSeconds(&now);
-	// Get current CLOCK_MONOTONIC time:
-	tMonotonic = PsychOSGetLinuxMonotonicTime();
-	// Given input monotonicTime time value closer to tMonotonic than to GetSecs time?
-	if (fabs(monotonicTime - tMonotonic) < fabs(monotonicTime - now)) {
-		// Timestamps are in monotonic time! Need to remap.
-		// tMonotonic shall be the offset between GetSecs and monotonic time,
-		// i.e., the offset that needs to be added to monotonic timestamps to
-		// remap them to GetSecs time:
-		tMonotonic = now - tMonotonic;
-		
-		// Correct timestamp by adding corrective offset:
-		monotonicTime += tMonotonic;
-	}
-
-	return(monotonicTime);
+    double now, now2, tMonotonic;
+    
+    // Get current reftime:
+    PsychGetAdjustedPrecisionTimerSeconds(&now);
+    // Get current CLOCK_MONOTONIC time:
+    tMonotonic = PsychOSGetLinuxMonotonicTime();
+    
+    // Given input monotonicTime time value closer to tMonotonic than to GetSecs time?
+    if (fabs(monotonicTime - tMonotonic) < fabs(monotonicTime - now)) {
+        // Timestamps are in monotonic time! Need to remap.
+        // Requery reference and monotonic time in a retry-loop
+        // to make sure remapping error is tighlty bounded to max. 20 usecs:
+        do {
+            // Get current reftime:
+            PsychGetAdjustedPrecisionTimerSeconds(&now);
+            // Get current CLOCK_MONOTONIC time:
+            tMonotonic = PsychOSGetLinuxMonotonicTime();
+            // Requery to make sure mapping is tight:
+            PsychGetAdjustedPrecisionTimerSeconds(&now2);
+        } while (now2 - now > 0.000020);
+        
+        // Computer average of both timestamps to get best estimate of "now":
+        now = (now + now2) / 2;
+        
+        // tMonotonic shall be the offset between GetSecs and monotonic time,
+        // i.e., the offset that needs to be added to monotonic timestamps to
+        // remap them to GetSecs time:
+        tMonotonic = now - tMonotonic;
+        
+        // Correct timestamp by adding corrective offset:
+        monotonicTime += tMonotonic;
+    }
+    
+    return(monotonicTime);
 }
 
 void PsychGetPrecisionTimerSeconds(double *secs)
@@ -677,3 +695,17 @@ psych_uint64 PsychAutoLockThreadToCores(psych_uint64* curCpuMask)
     // No op on Linux.
     return(INT64_MAX);
 }
+
+/* Report official support status for this operating system release.
+ * The string "Supported" means supported.
+ * Other strings describe lack of support.
+ */
+const char* PsychSupportStatus(void)
+{
+    static char statusString[256];
+    struct utsname unameresult;
+
+    uname(&unameresult);
+    sprintf(statusString, "Linux %s Supported.", unameresult.release);
+    return(statusString);
+}
