@@ -476,14 +476,6 @@ if strcmpi(cmd, 'Open')
         box.norelease = 0;
     end
 
-    if IsLinux
-        % Switch serial port to low-latency mode on Linux:
-        % This is extra-paranoid, as our udev rules and the
-        % 'ReceiveLatency=0.0001' setting below does already the same.
-        system(sprintf('setserial %s low_latency', port));
-        WaitSecs('YieldSecs', 0.100);
-    end
-
     % Try to open connection: Allocate an input buffer of a size of
     % 1600 * 9 * 3600 = 51840000 Bytes. This is sufficient for 1 hour of
     % uninterrupted box operation without ever reading out events from the
