@@ -605,7 +605,7 @@ try
         ni = conf.waitFramesSched(2:end);
         ni(conf.waitFramesSched == 0) = 1;
         ni = ni * ifi;
-        plot(ni * 1000, '--');
+        plot(ni * 1000, 'g--');
         title('Delta between successive Flips in milliseconds: (Dashed = expected delta)');
         hold off
 
@@ -653,29 +653,40 @@ try
     fprintf('Total of %i samples collected: %i\n', i);
     onsets = res.onsetFlipTime(1:i);
     % vbls: onsets = res.vblFlipTime(1:i);
-    %res.measuredTime = transpose(res.measuredTime(1:i));
-    difference = (res.measuredTime - onsets) * 1000;
+    difference = (onsets - res.measuredTime) * 1000;
     if ~IsOSX
         plot(difference);
-        title('Difference dt = MeasurementBOX - FlipOnset in msecs:');
+        title('Difference dt = FlipOnset - MeasurementBOX in msecs:');
     end
-    fprintf('Avg. diff. between Flip stimulus onset time and external timestamping (external - flip) is %f msecs, stddev = %f msecs, range = %f msecs.\n', mean(difference), std(difference), range(difference));
+    fprintf('Avg. diff. between Flip stimulus onset time and external timestamping (flip - external [ground truth]) is %f msecs, stddev = %f msecs, range = %f msecs.\n', mean(difference), std(difference), range(difference));
     
     % Count and output number of missed flip on VBL deadlines:
     numbermisses=0;
+    numberearly=0;
+
     for i=2:n
         numifis = conf.waitFramesSched(i);
         if numifis == 0
             numifis = 1;
         end
+
         if (res.vblFlipTime(i) - res.vblFlipTime(i-1) > ifi * ( numifis + 0.5 ))
             numbermisses=numbermisses+1;
-        end;
-    end;
+        end
+
+        if (res.vblFlipTime(i) - res.vblFlipTime(i-1) < ifi * ( numifis - 0.5 ))
+            numberearly=numberearly+1;
+        end
+    end
 
     % Output some summary and say goodbye...
     fprintf('PTB missed %i out of %i stimulus presentation deadlines.\n', numbermisses, n);
     fprintf('One missed deadline is ok and an artifact of the measurement.\n');
+    fprintf('PTB completed %i stimulus presentations before the requested target time.\n', numberearly);
+    if numberearly > 0
+        fprintf('CAUTION: Completing flips too early should *never ever happen*! Your system has\n');
+        fprintf('CAUTION: a serious bug or misconfiguration in its graphics driver!!!\n');
+    end
     fprintf('Have a look at the plots for more details...\n');
     
     % Close the audio device:
